@@ -49,6 +49,17 @@ NULL
 #'
 NULL
 
+#' Set base URL
+#'
+#' See \code{vegawidget::\link[vegawidget]{vw_set_base_url}} for details.
+#'
+#' @name vw_set_base_url
+#' @rdname vw_set_base_url
+#' @importFrom vegawidget vw_set_base_url
+#' @export
+#'
+NULL
+
 #### image functions ####
 
 #' Create or write image
